@@ -43,8 +43,8 @@ def shell_run(cmd):
     return lines
 
 
-def run_unit_tests(directory):
-    p = subprocess.Popen(['python3', f'{directory}/manage.py', 'test', '--keepdb'], stdout=subprocess.PIPE,
+def run_unit_tests(directory, apps=''):
+    p = subprocess.Popen(['python3', f'{directory}/manage.py', 'test', '--keepdb', apps], stdout=subprocess.PIPE,
                          stderr=subprocess.PIPE)  # nosec
     q = p.communicate()
     output = '\n'.join(x.decode('utf-8') for x in q)
