@@ -64,10 +64,10 @@ def run_qa(directory, verbose=False):
     # Unit tests garpix_page
     if 'garpix_page' in settings.INSTALLED_APPS:
         print_default('Django unit tests garpix_page')
-        garpix_tests_result = run_unit_tests(('garpix_page', ))
+        garpix_tests_result = run_unit_tests(directory, 'garpix_page')
 
-        if garpix_tests_result['failures']:
-            print_error(garpix_tests_result['output'])
+        if not garpix_tests_result.endswith("OK\n"):
+            print_error(garpix_tests_result)
             error_count += 1
         else:
             print_ok('', verbose)
